# This file has been generated


build_system = 'AppVeyor'
build_id = '29834759'
build_number = '428'
build_version = '1.0.428'
job_id = '09aljoyvygth22bt'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/stlib/build/job/09aljoyvygth22bt'
